# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/notebook/v1/kernel_service.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_notebook.gen.ai.h2o.notebook.v1 import kernel_pb2 as ai_dot_h2o_dot_notebook_dot_v1_dot_kernel__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/h2o/notebook/v1/kernel_service.proto\x12\x12\x61i.h2o.notebook.v1\x1a\x1f\x61i/h2o/notebook/v1/kernel.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"r\n\x13\x43reateKernelRequest\x12\x38\n\x06kernel\x18\x02 \x01(\x0b\x32\x1a.ai.h2o.notebook.v1.KernelB\x04\xe2\x41\x01\x02R\x06kernel\x12!\n\tkernel_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x08kernelId\"J\n\x14\x43reateKernelResponse\x12\x32\n\x06kernel\x18\x01 \x01(\x0b\x32\x1a.ai.h2o.notebook.v1.KernelR\x06kernel\"G\n\x10GetKernelRequest\x12\x33\n\x04name\x18\x01 \x01(\tB\x1f\xe2\x41\x01\x02\xfa\x41\x18\n\x16notebook.h2o.ai/KernelR\x04name\"G\n\x11GetKernelResponse\x12\x32\n\x06kernel\x18\x01 \x01(\x0b\x32\x1a.ai.h2o.notebook.v1.KernelR\x06kernel\"\\\n\x12ListKernelsRequest\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"s\n\x13ListKernelsResponse\x12\x34\n\x07kernels\x18\x01 \x03(\x0b\x32\x1a.ai.h2o.notebook.v1.KernelR\x07kernels\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x92\x01\n\x13UpdateKernelRequest\x12\x38\n\x06kernel\x18\x01 \x01(\x0b\x32\x1a.ai.h2o.notebook.v1.KernelB\x04\xe2\x41\x01\x02R\x06kernel\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02R\nupdateMask\"J\n\x14UpdateKernelResponse\x12\x32\n\x06kernel\x18\x01 \x01(\x0b\x32\x1a.ai.h2o.notebook.v1.KernelR\x06kernel\"J\n\x13\x44\x65leteKernelRequest\x12\x33\n\x04name\x18\x01 \x01(\tB\x1f\xe2\x41\x01\x02\xfa\x41\x18\n\x16notebook.h2o.ai/KernelR\x04name\"\x16\n\x14\x44\x65leteKernelResponse2\xc6\x05\n\rKernelService\x12\x91\x01\n\x0c\x43reateKernel\x12\'.ai.h2o.notebook.v1.CreateKernelRequest\x1a(.ai.h2o.notebook.v1.CreateKernelResponse\".\xda\x41\x10kernel,kernel_id\x82\xd3\xe4\x93\x02\x15\"\x0b/v1/kernels:\x06kernel\x12}\n\tGetKernel\x12$.ai.h2o.notebook.v1.GetKernelRequest\x1a%.ai.h2o.notebook.v1.GetKernelResponse\"#\xda\x41\x04name\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/{name=kernels/*}\x12s\n\x0bListKernels\x12&.ai.h2o.notebook.v1.ListKernelsRequest\x1a\'.ai.h2o.notebook.v1.ListKernelsResponse\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/kernels\x12\xa3\x01\n\x0cUpdateKernel\x12\'.ai.h2o.notebook.v1.UpdateKernelRequest\x1a(.ai.h2o.notebook.v1.UpdateKernelResponse\"@\xda\x41\x12kernel,update_mask\x82\xd3\xe4\x93\x02%2\x1b/v1/{kernel.name=kernels/*}:\x06kernel\x12\x86\x01\n\x0c\x44\x65leteKernel\x12\'.ai.h2o.notebook.v1.DeleteKernelRequest\x1a(.ai.h2o.notebook.v1.DeleteKernelResponse\"#\xda\x41\x04name\x82\xd3\xe4\x93\x02\x16*\x14/v1/{name=kernels/*}B\xd4\x01\n\x16\x63om.ai.h2o.notebook.v1B\x12KernelServiceProtoP\x01Z;github.com/h2oai/notebook/api/ai/h2o/notebook/v1;notebookv1\xa2\x02\x03\x41HN\xaa\x02\x12\x41i.H2o.Notebook.V1\xca\x02\x12\x41i\\H2o\\Notebook\\V1\xe2\x02\x1e\x41i\\H2o\\Notebook\\V1\\GPBMetadata\xea\x02\x15\x41i::H2o::Notebook::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.notebook.v1.kernel_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.ai.h2o.notebook.v1B\022KernelServiceProtoP\001Z;github.com/h2oai/notebook/api/ai/h2o/notebook/v1;notebookv1\242\002\003AHN\252\002\022Ai.H2o.Notebook.V1\312\002\022Ai\\H2o\\Notebook\\V1\342\002\036Ai\\H2o\\Notebook\\V1\\GPBMetadata\352\002\025Ai::H2o::Notebook::V1'
  _globals['_CREATEKERNELREQUEST'].fields_by_name['kernel']._options = None
  _globals['_CREATEKERNELREQUEST'].fields_by_name['kernel']._serialized_options = b'\342A\001\002'
  _globals['_CREATEKERNELREQUEST'].fields_by_name['kernel_id']._options = None
  _globals['_CREATEKERNELREQUEST'].fields_by_name['kernel_id']._serialized_options = b'\342A\001\002'
  _globals['_GETKERNELREQUEST'].fields_by_name['name']._options = None
  _globals['_GETKERNELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\030\n\026notebook.h2o.ai/Kernel'
  _globals['_LISTKERNELSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTKERNELSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTKERNELSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTKERNELSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEKERNELREQUEST'].fields_by_name['kernel']._options = None
  _globals['_UPDATEKERNELREQUEST'].fields_by_name['kernel']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEKERNELREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEKERNELREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _globals['_DELETEKERNELREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEKERNELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\030\n\026notebook.h2o.ai/Kernel'
  _globals['_KERNELSERVICE'].methods_by_name['CreateKernel']._options = None
  _globals['_KERNELSERVICE'].methods_by_name['CreateKernel']._serialized_options = b'\332A\020kernel,kernel_id\202\323\344\223\002\025\"\013/v1/kernels:\006kernel'
  _globals['_KERNELSERVICE'].methods_by_name['GetKernel']._options = None
  _globals['_KERNELSERVICE'].methods_by_name['GetKernel']._serialized_options = b'\332A\004name\202\323\344\223\002\026\022\024/v1/{name=kernels/*}'
  _globals['_KERNELSERVICE'].methods_by_name['ListKernels']._options = None
  _globals['_KERNELSERVICE'].methods_by_name['ListKernels']._serialized_options = b'\202\323\344\223\002\r\022\013/v1/kernels'
  _globals['_KERNELSERVICE'].methods_by_name['UpdateKernel']._options = None
  _globals['_KERNELSERVICE'].methods_by_name['UpdateKernel']._serialized_options = b'\332A\022kernel,update_mask\202\323\344\223\002%2\033/v1/{kernel.name=kernels/*}:\006kernel'
  _globals['_KERNELSERVICE'].methods_by_name['DeleteKernel']._options = None
  _globals['_KERNELSERVICE'].methods_by_name['DeleteKernel']._serialized_options = b'\332A\004name\202\323\344\223\002\026*\024/v1/{name=kernels/*}'
  _globals['_CREATEKERNELREQUEST']._serialized_start=245
  _globals['_CREATEKERNELREQUEST']._serialized_end=359
  _globals['_CREATEKERNELRESPONSE']._serialized_start=361
  _globals['_CREATEKERNELRESPONSE']._serialized_end=435
  _globals['_GETKERNELREQUEST']._serialized_start=437
  _globals['_GETKERNELREQUEST']._serialized_end=508
  _globals['_GETKERNELRESPONSE']._serialized_start=510
  _globals['_GETKERNELRESPONSE']._serialized_end=581
  _globals['_LISTKERNELSREQUEST']._serialized_start=583
  _globals['_LISTKERNELSREQUEST']._serialized_end=675
  _globals['_LISTKERNELSRESPONSE']._serialized_start=677
  _globals['_LISTKERNELSRESPONSE']._serialized_end=792
  _globals['_UPDATEKERNELREQUEST']._serialized_start=795
  _globals['_UPDATEKERNELREQUEST']._serialized_end=941
  _globals['_UPDATEKERNELRESPONSE']._serialized_start=943
  _globals['_UPDATEKERNELRESPONSE']._serialized_end=1017
  _globals['_DELETEKERNELREQUEST']._serialized_start=1019
  _globals['_DELETEKERNELREQUEST']._serialized_end=1093
  _globals['_DELETEKERNELRESPONSE']._serialized_start=1095
  _globals['_DELETEKERNELRESPONSE']._serialized_end=1117
  _globals['_KERNELSERVICE']._serialized_start=1120
  _globals['_KERNELSERVICE']._serialized_end=1830
# @@protoc_insertion_point(module_scope)
