# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/notebook/v1/kernel.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61i/h2o/notebook/v1/kernel.proto\x12\x12\x61i.h2o.notebook.v1\x1a\x19google/api/resource.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8e\x07\n\x06Kernel\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\'\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x64isplayName\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32\x1f.ai.h2o.notebook.v1.Kernel.TypeB\x04\xe2\x41\x01\x02R\x04type\x12\x1a\n\x05image\x18\x04 \x01(\tB\x04\xe2\x41\x01\x02R\x05image\x12%\n\x0b\x63pu_request\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x01R\ncpuRequest\x12!\n\tcpu_limit\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08\x63puLimit\x12\x30\n\x11gpu_resource_name\x18\x07 \x01(\tB\x04\xe2\x41\x01\x07R\x0fgpuResourceName\x12%\n\x0bgpu_request\x18\x08 \x01(\x05\x42\x04\xe2\x41\x01\x01R\ngpuRequest\x12!\n\tgpu_limit\x18\t \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08gpuLimit\x12\x36\n\x14memory_bytes_request\x18\n \x01(\x03\x42\x04\xe2\x41\x01\x01R\x12memoryBytesRequest\x12\x32\n\x12memory_bytes_limit\x18\x0b \x01(\x03\x42\x04\xe2\x41\x01\x01R\x10memoryBytesLimit\x12\x39\n\x16yaml_pod_template_spec\x18\x0c \x01(\tB\x04\xe2\x41\x01\x01R\x13yamlPodTemplateSpec\x12\x41\n\x0b\x63reate_time\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x1e\n\x07\x63reator\x18\x65 \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x46\n\x0bupdate_time\x18\x66 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03H\x00R\nupdateTime\x88\x01\x01\x12#\n\x07updater\x18g \x01(\tB\x04\xe2\x41\x01\x03H\x01R\x07updater\x88\x01\x01\"b\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bTYPE_PYTHON\x10\x01\x12\n\n\x06TYPE_R\x10\x02\x12\x15\n\x11TYPE_SPARK_PYTHON\x10\x03\x12\x10\n\x0cTYPE_SPARK_R\x10\x04:-\xea\x41*\n\x16notebook.h2o.ai/Kernel\x12\x10kernels/{kernel}B\x0e\n\x0c_update_timeB\n\n\x08_updaterB\xcd\x01\n\x16\x63om.ai.h2o.notebook.v1B\x0bKernelProtoP\x01Z;github.com/h2oai/notebook/api/ai/h2o/notebook/v1;notebookv1\xa2\x02\x03\x41HN\xaa\x02\x12\x41i.H2o.Notebook.V1\xca\x02\x12\x41i\\H2o\\Notebook\\V1\xe2\x02\x1e\x41i\\H2o\\Notebook\\V1\\GPBMetadata\xea\x02\x15\x41i::H2o::Notebook::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.notebook.v1.kernel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.ai.h2o.notebook.v1B\013KernelProtoP\001Z;github.com/h2oai/notebook/api/ai/h2o/notebook/v1;notebookv1\242\002\003AHN\252\002\022Ai.H2o.Notebook.V1\312\002\022Ai\\H2o\\Notebook\\V1\342\002\036Ai\\H2o\\Notebook\\V1\\GPBMetadata\352\002\025Ai::H2o::Notebook::V1'
  _globals['_KERNEL'].fields_by_name['name']._options = None
  _globals['_KERNEL'].fields_by_name['name']._serialized_options = b'\342A\001\003'
  _globals['_KERNEL'].fields_by_name['display_name']._options = None
  _globals['_KERNEL'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_KERNEL'].fields_by_name['type']._options = None
  _globals['_KERNEL'].fields_by_name['type']._serialized_options = b'\342A\001\002'
  _globals['_KERNEL'].fields_by_name['image']._options = None
  _globals['_KERNEL'].fields_by_name['image']._serialized_options = b'\342A\001\002'
  _globals['_KERNEL'].fields_by_name['cpu_request']._options = None
  _globals['_KERNEL'].fields_by_name['cpu_request']._serialized_options = b'\342A\001\001'
  _globals['_KERNEL'].fields_by_name['cpu_limit']._options = None
  _globals['_KERNEL'].fields_by_name['cpu_limit']._serialized_options = b'\342A\001\001'
  _globals['_KERNEL'].fields_by_name['gpu_resource_name']._options = None
  _globals['_KERNEL'].fields_by_name['gpu_resource_name']._serialized_options = b'\342A\001\007'
  _globals['_KERNEL'].fields_by_name['gpu_request']._options = None
  _globals['_KERNEL'].fields_by_name['gpu_request']._serialized_options = b'\342A\001\001'
  _globals['_KERNEL'].fields_by_name['gpu_limit']._options = None
  _globals['_KERNEL'].fields_by_name['gpu_limit']._serialized_options = b'\342A\001\001'
  _globals['_KERNEL'].fields_by_name['memory_bytes_request']._options = None
  _globals['_KERNEL'].fields_by_name['memory_bytes_request']._serialized_options = b'\342A\001\001'
  _globals['_KERNEL'].fields_by_name['memory_bytes_limit']._options = None
  _globals['_KERNEL'].fields_by_name['memory_bytes_limit']._serialized_options = b'\342A\001\001'
  _globals['_KERNEL'].fields_by_name['yaml_pod_template_spec']._options = None
  _globals['_KERNEL'].fields_by_name['yaml_pod_template_spec']._serialized_options = b'\342A\001\001'
  _globals['_KERNEL'].fields_by_name['create_time']._options = None
  _globals['_KERNEL'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_KERNEL'].fields_by_name['creator']._options = None
  _globals['_KERNEL'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_KERNEL'].fields_by_name['update_time']._options = None
  _globals['_KERNEL'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_KERNEL'].fields_by_name['updater']._options = None
  _globals['_KERNEL'].fields_by_name['updater']._serialized_options = b'\342A\001\003'
  _globals['_KERNEL']._options = None
  _globals['_KERNEL']._serialized_options = b'\352A*\n\026notebook.h2o.ai/Kernel\022\020kernels/{kernel}'
  _globals['_KERNEL']._serialized_start=149
  _globals['_KERNEL']._serialized_end=1059
  _globals['_KERNEL_TYPE']._serialized_start=886
  _globals['_KERNEL_TYPE']._serialized_end=984
# @@protoc_insertion_point(module_scope)
